Learn R Programming

anacor (version 1.0-5)

anacor-package: Simple and Canonical Correspondence Analysis

Description

This package performs simple and canonical CA on a two-way frequency table (with missings) by means of SVD. Different scaling methods (standard, centroid, Benzecri, Goodman) as well as various plots including confidence ellipsoids are provided.

Arguments

Details

ll{ Package: anacor Type: Package Version: 1.0-4 Date: 2013-11-30 License: GPL } The main function of the package is anacor() which performs simple CA. The input dataset tab is a (incomplete) frequency table. Various scaling options in terms of standard, centroid, Benzecri, and Goodman scaling are provided. They can be specified using the scaling argument. If covariates for row/column scores are provided, canonical CA will be computed. Utility functions to create various types of indicator matrices are implemented.

References

de Leeuw, J. and Mair, P. (2009). Simple and Canonical Correspondence Analysis Using the R Package anacor. Journal of Statistical Software, 31(5), 1-18.

See Also

anacor

Examples

Run this code
data(tocher)
res <- anacor(tocher)
res
summary(res)

Run the code above in your browser using DataLab