Learn R Programming

anacor (version 1.0-5)

glass: Glass data

Description

Table with occupational status of fathers versus occupational status of their sons for a sample of 3497 British families.

Usage

data(glass)

Arguments

References

Glass, D.V. (1954). Social Mobility in Britain. Glencoe: Free Press.

Examples

Run this code
data(glass)
## maybe str(glass) ; plot(glass) ...

Run the code above in your browser using DataLab