Learn R Programming

anacor (version 1.0-5)

bitterling: Bitterling

Description

This dataset concerns reproductive behavior of male bitterlings with data derived from 13 sequences using a moving time-window of size two.

Usage

data(bitterling)

Arguments

References

Wiepkema, P.R. (1961). An ethological analysis of the reproductive behavior of the bitterling (rhodeus amarus bloch). Archives Neerlandais Zoologique, 14, 103-199.

Examples

Run this code
data(bitterling)

Run the code above in your browser using DataLab